@@ -8,6 +8,7 @@
 # coding=utf-8
 # *** WARNING: generated file
 import typing
+import functools
 import dataclasses
 
 from panther_core import PantherEvent
@@ -56,6 +57,38 @@ SeverityCritical = "CRITICAL"
 ReportKeyMITRE = "MITRE ATT&CK"
 
 
+class DefaultOverrides:
+    pass
+
+
+def overridable(cls: typing.Callable) -> typing.Callable:
+    @functools.wraps(cls)
+    def wrapper(
+        *args: typing.Any,
+        overrides: typing.Optional[
+            typing.Union[
+                "DynamicStringFieldOverrides",
+                "DynamicDestinationsOverrides",
+                "AlertGroupingOverrides",
+                "PythonFilterOverrides",
+                "UnitTestMockOverrides",
+                "JSONUnitTestOverrides",
+                "PolicyOverrides",
+                "RuleOverrides",
+                "ScheduledRuleOverrides",
+                DefaultOverrides,
+            ]
+        ] = DefaultOverrides(),
+        **kwargs: typing.Any,
+    ) -> typing.Any:
+        if overrides:  # overrides can be None
+            for key, val in overrides.__dict__.items():
+                kwargs[key] = val or kwargs.get(key)
+        return cls(*args, **kwargs)
+
+    return wrapper
+
+
 @dataclasses.dataclass
 class DynamicStringFieldOverrides:
     """Overrides dataclass for DynamicStringField. All arguments are marked optional.
@@ -361,6 +394,7 @@ class PolicyOverrides:
     ] = None
 
 
+@overridable
 @dataclasses.dataclass(frozen=True)
 class Policy(_utilities.SDKNode):
     """Define a Policy-type detection to execute against log data in your Panther instance
@@ -445,6 +479,11 @@ class Policy(_utilities.SDKNode):
         ]
     ] = None
 
+    # overrides field is used to allow mypy type checking but is not used in Policy functionality
+    overrides: PolicyOverrides = dataclasses.field(
+        default=PolicyOverrides(), repr=False
+    )
+
     # internal private methods
     def _typename(self) -> str:
         return "Policy"
@@ -547,6 +586,7 @@ class RuleOverrides:
     ] = None
 
 
+@overridable
 @dataclasses.dataclass(frozen=True)
 class Rule(_utilities.SDKNode):
     """Define a Rule-type detection to execute against log data in your Panther instance
@@ -635,6 +675,9 @@ class Rule(_utilities.SDKNode):
         ]
     ] = None
 
+    # overrides field is used to allow mypy type checking but is not used in Rule functionality
+    overrides: RuleOverrides = dataclasses.field(default=RuleOverrides(), repr=False)
+
     # internal private methods
     def _typename(self) -> str:
         return "Rule"
@@ -738,6 +781,7 @@ class ScheduledRuleOverrides:
     ] = None
 
 
+@overridable
 @dataclasses.dataclass(frozen=True)
 class ScheduledRule(_utilities.SDKNode):
     """Define a ScheduledRule-type detection to execute against query results in your Panther instance
@@ -826,6 +870,11 @@ class ScheduledRule(_utilities.SDKNode):
         ]
     ] = None
 
+    # overrides field is used to allow mypy type checking but is not used in ScheduledRule functionality
+    overrides: ScheduledRuleOverrides = dataclasses.field(
+        default=ScheduledRuleOverrides(), repr=False
+    )
+
     # internal private methods
     def _typename(self) -> str:
         return "ScheduledRule"
