@@ -8,6 +8,7 @@
 # coding=utf-8
 # *** WARNING: generated file
 import typing
+import functools
 import dataclasses
 
 from panther_core import PantherEvent
@@ -34,6 +35,32 @@ DatalakeAthena = "athena"
 DatalakeSnowflake = "snowflake"
 
 
+class DefaultOverrides:
+    pass
+
+
+def overridable(cls: typing.Callable) -> typing.Callable:
+    @functools.wraps(cls)
+    def wrapper(
+        *args: typing.Any,
+        overrides: typing.Optional[
+            typing.Union[
+                "CronScheduleOverrides",
+                "IntervalScheduleOverrides",
+                "QueryOverrides",
+                DefaultOverrides,
+            ]
+        ] = DefaultOverrides(),
+        **kwargs: typing.Any,
+    ) -> typing.Any:
+        if overrides:  # overrides can be None
+            for key, val in overrides.__dict__.items():
+                kwargs[key] = val or kwargs.get(key)
+        return cls(*args, **kwargs)
+
+    return wrapper
+
+
 @dataclasses.dataclass
 class CronScheduleOverrides:
     """Overrides dataclass for CronSchedule. All arguments are marked optional.
